@@ -3,12 +3,14 @@
 # with color and name.
 
 import IMP.display
+import sys
+
+IMP.setup_from_argv(
+    sys.argv,
+    "Write basic geometric primitives to a file with color and name.")
 
-# or IMP.display.ChimeraWriter
-# if using chimera, make sure there is a %1% in the name to support
-# multiple frames
 name = IMP.create_temporary_file_name("example", ".py")
-print "File name is", name
+print("File name is", name)
 w = IMP.display.PymolWriter(name)
 
 bb = IMP.algebra.BoundingBox3D(IMP.algebra.Vector3D(0, 0, 0),
