@@ -4,6 +4,9 @@
 
 import IMP
 import IMP.kmeans
+import sys
+
+IMP.setup_from_argv(sys.argv, "kmeans example")
 
 
 def add_points(km):
@@ -18,26 +21,27 @@ def add_points(km):
     km.add_data_pt([9.2, 11])
     km.add_data_pt([0, 0])
 
-IMP.base.set_log_level(IMP.base.PROGRESS)
+
+IMP.set_log_level(IMP.PROGRESS)
 km = IMP.kmeans.KMeans()
 add_points(km)
 # cluster data
 k = 2
 km.execute(k)
 # print centers one by one
-print "\nCenters:"
+print("\nCenters:")
 nCenters = km.get_number_of_centers()  # this should actually be equal to k
-print "Number of centers (k): ", nCenters
+print("Number of centers (k): ", nCenters)
 for i in range(0, nCenters):
-    print "Center ", i, "   ", km.get_center(i)
+    print("Center ", i, "   ", km.get_center(i))
 
 # print data point assignments
 n = km.get_number_of_data_points()
 assignments = km.get_assignments()
 sqrdist = km.get_squared_distance_to_centers()
-print "Number of points: ", n
+print("Number of points: ", n)
 for i in range(0, n):
-    print "Point ", i, ": "
-    print km.get_data_point(i)
-    print "Cluster center: ", assignments[i], \
-        " sqrt-dist: ", sqrdist[i]
+    print("Point ", i, ": ")
+    print(km.get_data_point(i))
+    print("Cluster center: ", assignments[i],
+          " sqrt-dist: ", sqrdist[i])
